@@ -17,46 +17,47 @@ DIFF_ID_LENGTH = 7  # Dxxxxxx
 
 
 def _darken(in_s: str) -> str:
-    """returns a darkened string"""
+    """Returns a darkened string"""
     return colored(in_s, attrs=['dark'])
 
 
 def _underline(in_s: str) -> str:
-    """returns an underlined string"""
+    """Returns an underlined string"""
     return colored(in_s, attrs=['underline'])
 
 
 def _green(in_s: str) -> str:
-    """returns a green string"""
+    """Returns a green string"""
     return colored(in_s, 'green')
 
 
 def _red(in_s: str) -> str:
-    """returns a red string"""
+    """Returns a red string"""
     return colored(in_s, 'red')
 
 
 def _cyan(in_s: str) -> str:
-    """returns a cyan string"""
+    """Returns a cyan string"""
     return colored(in_s, 'cyan')
 
 
 def _yellow(in_s: str) -> str:
-    """returns a yellow string"""
+    """Returns a yellow string"""
     return colored(in_s, 'yellow')
 
 
 def _green(in_s: str) -> str:
-    """returns a green string"""
+    """Returns a green string"""
     return colored(in_s, 'green')
 
 
 def _blue(in_s: str) -> str:
-    """returns a blue string"""
+    """Returns a blue string"""
     return colored(in_s, 'blue')
 
 
 def _truncate_string(str_input: str, max_length: str) -> str:
+    """Truncates the string to a specified length"""
     str_end = '...'
     length = len(str_input)
     if length > max_length:
@@ -64,6 +65,11 @@ def _truncate_string(str_input: str, max_length: str) -> str:
     return str_input
 
 
+def _get_term_width() -> int:
+    """Gets the term width (amount of characters per line)"""
+    return os.get_terminal_size().columns
+
+
 def commit_summary(cmt: Commit, short=True) -> str:
     """Returns an inline summary of a given commit"""
     hsh = get_short_hash(cmt)
@@ -71,8 +77,9 @@ def commit_summary(cmt: Commit, short=True) -> str:
     time = naturaltime(datetime.now() - cmt.committed_datetime.replace(tzinfo=None))
     status = get_diff_id(cmt) if has_diff_attached(cmt) else "N/A".center(DIFF_ID_LENGTH)
 
-    term_width = os.get_terminal_size().columns
-    msg = _truncate_string(cmt.message, term_width - DIFF_ID_LENGTH - len(hsh + author + time) - 10)
+    term_width = _get_term_width()
+    msg = _truncate_string(cmt.message, term_width - DIFF_ID_LENGTH -
+                           len(hsh + author + time + status) - 10)
     msg = ' '.join(msg.split())
 
     hsh = _red(hsh)
@@ -86,8 +93,23 @@ def commit_summary(cmt: Commit, short=True) -> str:
         return f"{status} - {hsh} - {msg} ({time}) <{author}>"
 
 
+def print_base(base: str, cmt: Commit):
+    """Prints the base tag and the base commit"""
+    line_char = '-'
+    base_header = "Base -> "
+    base_text = f'└-{base_header}{base} (shown below) '
+    # using ^ as it's illegal in tag names
+    base_placeholder = '^' * len(base_text)
+    width = _get_term_width() - 6
+    print(base_placeholder
+          .ljust(width, line_char)
+          .replace(' ', line_char)
+          .replace(base_placeholder, _darken(_yellow(base_text))))
+    print(commit_summary(cmt, short=False))
+
+
 def print_update_msg(current_commit: Commit, current_diff_id: str, update_message: str):
-    """print msg for updating an diff"""
+    """Prints msg for updating an diff"""
     print(
         f"{_blue('Update')} {_yellow(current_diff_id)} with"
         + f" {commit_summary(current_commit)}"
@@ -95,17 +117,17 @@ def print_update_msg(current_commit: Commit, current_diff_id: str, update_messag
 
 
 def print_submit_msg(current_commit: Commit, prev_commit: Commit):
-    """print msg for submitting an diff"""
+    """Prints msg for submitting an diff"""
     print(
         f"{_green('Submit')} {commit_summary(current_commit)}"
         + f" based on {commit_summary(prev_commit)}.")
 
 
 def print_error(err_msg):
-    """print msg to stderr"""
+    """Prints red msg to stderr"""
     print(_red(err_msg), file=sys.stderr)
 
 
 def print_warning(err_msg):
-    """print msg to stderr"""
+    """Prints yellow msg to stdout"""
     print(_yellow(err_msg), file=sys.stdout)
