@@ -18,40 +18,61 @@ from stackler.git_utils import REPO_PATH, BASE_TAG
 app = typer.Typer()
 
 
+arg_sha = typer.Argument(..., help="The SHA to the commit")
+
+option_base = typer.Option(
+    BASE_TAG,
+    "--base", "-b",
+    help='The base commit of the stack')
+option_update_message = typer.Option(
+    '',
+    "--update-message", "-m",
+    help='The message for updating a diff')
+option_dry_run = typer.Option(
+    False,
+    "--dry-run", "-n",
+    help='Print which commits are going to be submitted, but doesn\'t submit anything')
+option_interactive_submit = typer.Option(
+    False,
+    "--interactive-submit", "-i",
+    help='Use this flag if you want to manually enter the diff summary for new commits')
+
+
 @app.command()
-def submit(base: str = typer.Option(BASE_TAG, "--base", "-b"),
-           update_message: str = typer.Option(
-               '', "--update-message", "-m", help='The message for updating a diff'),
-           dry_run: bool = typer.Option(
-               False,
-               "--dry-run", "-n",
-               help='Print which commits are going to be submitted, but doesn\'t submit anything'),
-           debug_dry_run: bool = False):
+def submit(
+        base: str = option_base,
+        interactive_submit: bool = option_interactive_submit,
+        update_message: str = option_update_message,
+        dry_run: bool = option_dry_run,
+        debug_dry_run: bool = False):
     """
     Submit a stack of commits separately.
     Use -b to specify a base if you aren't working on <develop>.
     """
     _precheck(base)
-    _submit(base=base,
-            update_message=update_message,
-            dry_run=dry_run,
-            debug_dry_run=debug_dry_run,
+    _submit(base,
+            interactive_submit,
+            update_message,
+            dry_run,
+            debug_dry_run,
             prompt_dry_run=False)
 
 
-def _submit(base: str = BASE_TAG,
-            update_message: str = '',
-            dry_run: bool = False,
-            debug_dry_run: bool = False,
+def _submit(base: str,
+            interactive_submit: bool,
+            update_message: str,
+            dry_run: bool,
+            debug_dry_run: bool,
             prompt_dry_run=False):
 
     # do an internal dry run to show the prompt
     if not dry_run and not debug_dry_run and not prompt_dry_run:
         print("By continuing, this script will:")
-        _submit(base=base,
-                update_message=update_message,
-                dry_run=dry_run,
-                debug_dry_run=debug_dry_run,
+        _submit(base,
+                interactive_submit,
+                update_message,
+                dry_run,
+                debug_dry_run,
                 prompt_dry_run=True)
         if not click.confirm('Do you want to continue?', default=True):
             display_utils.print_error('Aborted')
@@ -79,13 +100,14 @@ def _submit(base: str = BASE_TAG,
     # 1. find the base commit
     current_commit = prev_commits[-1]
     if base_commit == current_commit:
-        print("No commit to submit")
+        print("No commits to submit")
         return
 
     # 2. go through the stack of commits
     prev_commit = base_commit
     prev_diff_id = ''
     current_diff_id = ''
+    has_updates = False
     for i in range(len(prev_commits)):
         # sanity check:
         # Base - A - B - C - D
@@ -100,6 +122,7 @@ def _submit(base: str = BASE_TAG,
         is_updating = phab_utils.has_diff_attached()
         if is_updating:
             current_diff_id = phab_utils.get_diff_id()
+            has_updates = True
 
         # show msgs
         if is_updating:
@@ -114,7 +137,19 @@ def _submit(base: str = BASE_TAG,
             if is_updating and update_message:
                 arc_args.append('-m')
                 arc_args.append(update_message)
-            subprocess.run(arc_args, check=True)
+            if (not is_updating) and (not interactive_submit):
+                arc_args.append("--verbatim")
+            try:
+                subprocess.run(arc_args, check=True)
+            except subprocess.CalledProcessError:
+                display_utils.print_warning(
+                    "arc sumbit failed. Starting over."
+                )
+                print(
+                    f"The command ran: {' '.join(arc_args)}"
+                )
+                repo.git.checkout(current_branch)
+                sys.exit(1)
 
             # 2b. connect the diff with previous one
             current_diff_id = phab_utils.get_diff_id()
@@ -133,13 +168,19 @@ def _submit(base: str = BASE_TAG,
         repo.git.checkout(current_branch)
         repo.git.rebase(prev_commit.hexsha)
 
+    if prompt_dry_run and has_updates and not update_message:
+        display_utils.print_warning(
+            "You have not specified an update message. " +
+            "Make sure you manually add one for all the diff updates, or the operation would fail."
+        )
+
     # 3. move HEAD to new tip
     # already performed
 
 
-@app.command()
-def edit(sha: str = typer.Argument(..., help="The SHA to the commit"),
-         base: str = typer.Option(BASE_TAG, "--base", "-b")):
+@ app.command()
+def edit(sha: str = arg_sha,
+         base: str = option_base):
     """
     Allows you to edit a commit within a stack easily.
     This is basically just a wrapper for `git rebase sha^`)
@@ -149,8 +190,8 @@ def edit(sha: str = typer.Argument(..., help="The SHA to the commit"),
     if not git_utils.is_commit_in_stack(sha, tip='HEAD', base=base):
         display_utils.print_error(
             f"The commit <{sha[:8]}> isn't in the stack.")
-        print("Stackler only supports editing a commit in the working stack.")
-        # TODO: print stack
+        print("Stackler only supports editing a commit in the working stack:")
+        show(base)
         sys.exit(1)
 
     editor_cmd = "sed -i -re '1s/pick/e/'"
@@ -161,16 +202,18 @@ def edit(sha: str = typer.Argument(..., help="The SHA to the commit"),
 
 
 @app.command()
-def show(base: str = typer.Option(BASE_TAG, "--base", "-b")):
+def show(base: str = option_base):
     """
     Prints the stack.
     """
+    _precheck(base)
     repo = Repo(REPO_PATH)
     commits = list(repo.iter_commits(f"{base}..HEAD"))
-    for commit in commits:
-        print(display_utils.commit_summary(commit, short=False))
-    print('---- BASE ----')
-    print(display_utils.commit_summary(repo.commit(f"{base}"), short=False))
+    if not commits:
+        display_utils.print_warning('No commits in the stack.')
+    for i, commit in enumerate(commits):
+        print(('| ' if i > 0 else '↑ ') + display_utils.commit_summary(commit, short=False))
+    display_utils.print_base(base, repo.commit(f"{base}"))
 
 
 def _precheck(base: str):
